<?php

namespace Drupal\ai_comment_moderation\Service;

use GuzzleHttp\ClientInterface;
use Psr\Log\LoggerInterface;
use Drupal\Core\Config\ConfigFactoryInterface;

/**
 * Provides OpenAI-powered comment moderation service.
 */
class AiModerationService {

  /**
   * The HTTP client for API calls.
   *
   * @var \GuzzleHttp\ClientInterface
   */
  protected $httpClient;

  /**
   * The logger service.
   *
   * @var \Psr\Log\LoggerInterface
   */
  protected $logger;

  /**
   * The configuration factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * Constructs the AI moderation service.
   *
   * @param \GuzzleHttp\ClientInterface $http_client
   *   The HTTP client.
   * @param \Psr\Log\LoggerInterface $logger
   *   The logger.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   The config factory.
   */
  public function __construct(ClientInterface $http_client, LoggerInterface $logger, ConfigFactoryInterface $configFactory) {
    $this->httpClient = $http_client;
    $this->logger = $logger;
    $this->configFactory = $configFactory;
  }

  /**
   * Sends comment text to OpenAI Moderation API and returns if it's flagged.
   *
   * @param string $text
   *   The user comment text to moderate.
   *
   * @return bool
   *   TRUE if flagged as inappropriate, FALSE otherwise.
   */
  public function moderateText($text) {
    $api_key = $this->configFactory->get('ai_comment_moderation.settings')->get('openai_api_key');

    try {
      $response = $this->httpClient->request('POST', 'https://api.openai.com/v1/moderations', [
        'headers' => [
          'Authorization' => "Bearer $api_key",
          'Content-Type' => 'application/json',
        ],
        'json' => [
          'input' => $text,
        ],
      ]);

      $body = json_decode($response->getBody(), TRUE);
      return $body['results'][0]['flagged'] ?? FALSE;
    }
    catch (\Exception $e) {
      $this->logger->error($e->getMessage());
      return FALSE;
    }
  }

}
